// server/index.js
const express = require('express');
const cors = require('cors');
const { PrismaClient } = require('@prisma/client');

const app = express();
const prisma = new PrismaClient();

app.use(cors());
app.use(express.json());

app.get('/', (req, res) => {
    res.json({ message: 'Welcome to the server API!' });
});

// Test endpoint to ensure Prisma is connected to the database
app.get('/test-db', async (req, res) => {
    try {
        const response = await prisma.$queryRaw`SELECT 1 + 1 AS solution`;
        res.status(200).json({ solution: response[0].solution });
    } catch (err) {
        res.status(500).send(err.message);
    }
});

// Using Prisma Client to get subtopics data
app.get('/subtopics', async (req, res) => {
    try {
        const subtopics = await prisma.subtopic.findMany();
        res.json(subtopics);
    } catch (err) {
        res.status(500).send(err.message);
    }
});

// Start the server
const PORT = process.env.PORT || 5000;
app.listen(PORT, () => {
    console.log(`Server running on port ${PORT}`);
});
