// src/App.js
import React, { useState, useEffect } from 'react';
import { BrowserRouter as Router, Routes, Route, Navigate } from 'react-router-dom';
import Home from './Home';
import About from './About'; 
import Insights from './Insights';
import Navbar from './Navbar';
import LoginPage from './LoginPage';
import { testDbConnection } from '../api/api'; 

function App() {
  const [isLoggedIn, setIsLoggedIn] = useState(false);
  const [dbTestResult, setDbTestResult] = useState(null);

  const handleLoginSuccess = () => {
    setIsLoggedIn(true);
  };

  const handleTestDbConnection = async () => {
    try {
      const response = await testDbConnection();
      setDbTestResult(response);
      console.log(response);
    } catch (error) {
      console.error('Database test failed:', error);
      setDbTestResult(null);
    }
  };

  // Test the database connection once when the app is loaded
  useEffect(() => {
    handleTestDbConnection();
  }, []);

  return (
    <Router>
      <Navbar />
      <Routes>
        {isLoggedIn ? (
          // Render these routes only if the user is logged in
          <>
            <Route path="/about" element={<About />} />
            <Route path="/insights" element={<Insights />} />
            <Route path="/" element={<Home onTestDbConnection={handleTestDbConnection} dbTestResult={dbTestResult} />} />
          </>
        ) : (
          // If not logged in, redirect to login page
          <>
            <Route path="/login" element={<LoginPage onLoginSuccess={handleLoginSuccess} />} />
            <Route path="*" element={<Navigate replace to="/login" />} />
          </>
        )}
      </Routes>
    </Router>
  );
}

export default App;
